@@ -1,5 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
+ * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -26,6 +28,7 @@
 #define __PAROLE_STREAM_H
 
 #include <glib-object.h>
+#include <gdk/gdkx.h>
 
 G_BEGIN_DECLS
 
@@ -46,6 +49,18 @@ typedef enum
     
 } ParoleMediaType;
 
+
+typedef enum
+{
+    PAROLE_STATE_STOPPED = 0,
+    PAROLE_STATE_PLAYBACK_FINISHED,
+    PAROLE_STATE_ABOUT_TO_FINISH,
+    PAROLE_STATE_PAUSED,
+    PAROLE_STATE_PLAYING
+    
+} ParoleState;
+
+
 typedef struct _ParoleStream      ParoleStream;
 typedef struct _ParoleStreamClass ParoleStreamClass;
 
@@ -62,6 +77,10 @@ struct _ParoleStreamClass
 
 GType        			parole_stream_get_type        (void) G_GNUC_CONST;
 
+void parole_stream_set_image (GObject *object, GdkPixbuf *pixbuf);
+
+GdkPixbuf *parole_stream_get_image (GObject *object);
+
 ParoleStream       	       *parole_stream_new             (void);
 
 void			        parole_stream_init_properties (ParoleStream *stream);
